@@ -3,6 +3,7 @@ package Test::DZP::Changes;
 use Test::Roo::Role;
 use Test::DZil;
 use Test::CPAN::Changes;
+use Test::TempDir::Tiny;
 use Archive::Tar;
 use File::chdir;
 use Dist::Zilla::File::InMemory;
@@ -15,6 +16,10 @@ has test_repo      => (is => 'lazy');
 has tzil           => (is => 'lazy', clearer  => 1);
 has tzil_ini       => (is => 'rw');
 
+has _test_data_dir => (
+    is      => 'ro',
+    default => sub { path('t', 'data') });
+
 # initialise the Dzil test builder object
 sub _build_tzil {
     my $self = shift;
@@ -44,10 +49,19 @@ sub _set_tzil_ini_opts {
 # extracts the test git repo from a tarball
 sub _build_test_repo {
     my $self = shift;
-    local $CWD = 't';
-    diag 'Extracting test repo';
-    Archive::Tar->extract_archive($self->test_repo_name . '.tar.gz');
-    return path('t/' . $self->test_repo_name);
+
+    my $repo_dir = path(tempdir);
+    my $repo_archive =
+      $self->_test_data_dir->child('repos', $self->test_repo_name . '.tar.gz')
+      ->absolute;
+
+    local $CWD = $repo_dir;    ## no critic (ProhibitLocalVars)
+
+    diag "Extracting $repo_archive to $repo_dir";
+
+    Archive::Tar->extract_archive($repo_archive);
+
+    return $repo_dir->child($self->test_repo_name)->absolute;
 }
 
 after teardown => sub { shift->test_repo->remove_tree({safe => 0}) };
@@ -61,10 +75,13 @@ sub test_changes {
     my $changes_file = $self->tzil->tempdir->child('build/Changes');
     changes_file_ok $changes_file;
 
-    my $expected_file    = path "t/changes/$expected_name";
+    my $expected_file =
+      $self->_test_data_dir->child('changes', $expected_name);
     my @expected_changes = $expected_file->lines_utf8;
     my @got_changes      = $changes_file->lines_utf8;
 
+    diag "Comparing $changes_file to $expected_file";
+
     # everything should match except the date
     foreach (my $i = 0 ; $i < scalar @expected_changes ; $i++) {
         if ($expected_changes[$i] =~ /^\d+\.\d{3}/) {
